@@ -51,7 +51,16 @@ public:
         InteractiveMoveRole, // This output is currently repositioned interactively
         BrightnessRole,
         ColorPowerPreference,
+        DdcCiAllowedRole,
+        MaxBitsPerColorRole,
+        AutomaticMaxBitsPerColorLimitRole,
+        MinSupportedMaxBitsPerColorRole,
+        MaxSupportedMaxBitsPerColorRole,
+        PeakBrightnessOverride,
+        OutputNameRole,
+        EdrPolicyRole,
     };
+    Q_ENUM(OutputRoles)
 
     explicit OutputModel(ConfigHandler *configHandler);
     ~OutputModel() override = default;
@@ -63,6 +72,8 @@ public:
     void add(const KScreen::OutputPtr &output);
     void remove(int outputId);
 
+    QModelIndex indexForOutput(const KScreen::OutputPtr &output) const;
+
     /**
      * Resets the origin for calculation of positions to the most northwest display corner
      * while keeping the normalized positions untouched.
