@@ -10,6 +10,7 @@
 #include <QObject>
 #include <QString>
 #include <QTimer>
+#include <qqmlregistration.h>
 
 #include "../common/osdaction.h"
 
@@ -19,6 +20,13 @@ class ConfigOperation;
 class Osd;
 class Output;
 
+struct OsdActionForeign : public QObject {
+    Q_OBJECT
+    QML_NAMED_ELEMENT(OsdAction)
+    QML_UNCREATABLE("Only for enums")
+    QML_EXTENDED_NAMESPACE(KScreen::OsdAction)
+};
+
 class OsdManager : public QObject
 {
     Q_OBJECT
